confint.RMA.Exact: Compute a confidence interval for the population mean from an RMA.Exact object
Description
A warning will be issued if the reported endpoints of the confidence interval are near the bounding box.
Usage
# S3 method for RMA.Exact
confint(object, parm, level = 0.05, ...)
Arguments
object
an object of class RMA.Exact
level
the significance levels at which the compute the confidence intervals
...
(currently for internal use)
Value
a matrix with a row corresponding to each weight parameter c0 stored in rma0, and columns containing the upper and lower interval endpoints, the population variance values at whcih those
endpoints were obtained, etc.
Examples
Run this code# NOT RUN {
## see ?RMA.Exact
# }
Run the code above in your browser using DataLab