vector of the mixing parameters for the test statistics
level
the level of the confidence interval
plot
indicator whether to plot the contour of the confidence region
tau2.bounds
upper and lower bounds for the range of population variance values for constructing the confidence region; if NULL, value will be calculated from tau2.alpha
resolution
resolution of the population variance values for constructing the confidence region
Z
a matrix of length(yi) rows with each row consisting of standard normal samples to be used in the monte carlo estimation of the null distribution of the test statistic; if NULL, B values
will be sampled per row
B
the number of monte carlo replicates per primary study observation to be used
tau2.alpha
the level of the exact CI with which to bounds on population variance when constructing the confidence region
Value
a matrix with length(c0) rows and each row containing the lower and upper endpoints of the confidence interval for the given mixing parameter